==> qore-0.9.3.tar.bz2: qore-0.9.3/docs/modules/SmtpClient/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SmtpClient Module Reference", "index.html", [
    [ "SmtpClient Module", "index.html", [
      [ "SmtpClient Introduction", "index.html#smtpclientintro", null ],
      [ "SmtpClient References", "index.html#smtpclient_references", null ],
      [ "SmtpClient Release Notes", "index.html#smtpclient_relnotes", [
        [ "SmtpClient 1.7", "index.html#smtpclient_v1_7", null ],
        [ "SmtpClient 1.6", "index.html#smtpclient_v1_6", null ],
        [ "SmtpClient 1.5", "index.html#smtpclient_v1_5", null ],
        [ "SmtpClient 1.4", "index.html#smtpclient_v1_4", null ],
        [ "SmtpClient 1.3", "index.html#smtpclient_v1_3", null ],
        [ "SmtpClient 1.2", "index.html#smtpclient_v1_2", null ],
        [ "SmtpClient 1.1", "index.html#smtpclient_v1_1", null ],
        [ "SmtpClient 1.0", "index.html#smtpclient_v1_10", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/SmtpClient/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SmtpClient Module Reference", "index.html", [
    [ "SmtpClient Module", "index.html", [
      [ "SmtpClient Introduction", "index.html#smtpclientintro", null ],
      [ "SmtpClient References", "index.html#smtpclient_references", null ],
      [ "SmtpClient Release Notes", "index.html#smtpclient_relnotes", [
        [ "SmtpClient 1.9", "index.html#smtpclient_v1_9", null ],
        [ "SmtpClient 1.8", "index.html#smtpclient_v1_8", null ],
        [ "SmtpClient 1.7", "index.html#smtpclient_v1_7", null ],
        [ "SmtpClient 1.6", "index.html#smtpclient_v1_6", null ],
        [ "SmtpClient 1.5", "index.html#smtpclient_v1_5", null ],
        [ "SmtpClient 1.4", "index.html#smtpclient_v1_4", null ],
        [ "SmtpClient 1.3", "index.html#smtpclient_v1_3", null ],
        [ "SmtpClient 1.2", "index.html#smtpclient_v1_2", null ],
        [ "SmtpClient 1.1", "index.html#smtpclient_v1_1", null ],
        [ "SmtpClient 1.0", "index.html#smtpclient_v1_10", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
